OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Impossible d’escriure dins lo repertòri « config » !",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Aqueste problèma es generalament resolgut en donant al servidor web un accès en escritura al repertòri \"config\"",
    "See %s" : "Veire %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Aqueste problèma es generalament resolgut %sen donant al servidor web un accès en escritura al repertòri de configuracion%s.",
    "Sample configuration detected" : "Configuracion d'exemple detectada",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Es estat detectat que la configuracion donada a títol d'exemple es estada copiada. Aquò pòt rendre vòstra installacion inoperanta e es pas pres en carga. Legissètz la documentacion abans d'efectuar de modifications dins config.php",
    "PHP %s or higher is required." : "PHP %s o superior es requesit.",
    "PHP with a version lower than %s is required." : "PHP amb una version anteriora a %s es requesit.",
    "%sbit or higher PHP required." : "%sbit o PHP superior es requesit.",
    "Following databases are supported: %s" : "Les bases de donadas seguentas son suportadas : %s",
    "The command line tool %s could not be found" : "La comanda %s es introbabla",
    "The library %s is not available." : "La bibliotèca %s es pas disponibla.",
    "Library %s with a version higher than %s is required - available version %s." : "La bibliotèca %s deu èsser al mens a la version %s. Version disponibla : %s.",
    "Library %s with a version lower than %s is required - available version %s." : "La bibliotèca %s deu aver una version anteriora a %s. Version disponibla : %s.",
    "Following platforms are supported: %s" : "Las plataformas seguentas son presas en carga : %s",
    "ownCloud %s or higher is required." : "ownCloud %s o superior es requesit.",
    "ownCloud %s or lower is required." : "ownCloud %s o inferior es requesit.",
    "Unknown filetype" : "Tipe de fichièr desconegut",
    "Invalid image" : "Imatge pas valable",
    "Avatar image is not square" : "L'imatge de l'avatar es pas carrat",
    "today" : "uèi",
    "yesterday" : "ièr",
    "_%n day ago_::_%n days ago_" : ["i a %n jorn","i a %n jorns"],
    "last month" : "lo mes passat",
    "_%n month ago_::_%n months ago_" : ["I a %n mes","I a %n meses"],
    "last year" : "l'an passat",
    "_%n year ago_::_%n years ago_" : ["i a %n an","i a %n ans"],
    "_%n minute ago_::_%n minutes ago_" : ["i a %n minuta","i a %n minutas"],
    "seconds ago" : "i a qualques segondas",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Lo modul amb l'id: %s existís pas. Mercé de l'activar dins los paramètres d'aplicacions o de contactar vòstre administrator.",
    "Builtin" : "Integrat",
    "None" : "Pas cap",
    "Username and password" : "Nom d'utilizaire e senhal",
    "Username" : "Identificant",
    "Password" : "Senhal",
    "Log-in credentials, save in session" : "Identificants de connexion, salvats per la session",
    "Empty filename is not allowed" : "Lo nom de fichièr pòt pas èsser void",
    "Dot files are not allowed" : "Lo nom de fichièr pòt pas començar per un punt",
    "4-byte characters are not supported in file names" : "Los caractèrs sus 4 octets son pas preses en carga dins los noms de fichièrs",
    "File name is a reserved word" : "Aqueste nom de fichièr es un mot reservat",
    "File name contains at least one invalid character" : "Lo nom de fichièr conten un (de) caractèr(s) invalid(s)",
    "File name is too long" : "Nom de fichièr tròp long",
    "App directory already exists" : "Lo dorsièr de l'aplicacion existís ja",
    "Can't create app folder. Please fix permissions. %s" : "Impossible de crear lo dorsièr de l'aplicacion. Corregissètz los dreches d'accès. %s",
    "Archive does not contain a directory named %s" : "Lo fichièr archiu conten pas de repertòri %s",
    "No source specified when installing app" : "Cap de font pas especificada per installar l'aplicacion",
    "No href specified when installing app from http" : "Cap de href pas especificat per installar l'aplicacion per http",
    "No path specified when installing app from local file" : "Cap de camin pas especificat per installar l'aplicacion dempuèi un fichièr local",
    "Archives of type %s are not supported" : "Los archius de tipe %s son pas preses en carga",
    "Failed to open archive when installing app" : "Fracàs de la dobertura de l'archiu al moment de l'installacion de l'aplicacion",
    "App does not provide an info.xml file" : "L'aplicacion provesís pas cap de fichièr info.xml",
    "App can't be installed because of not allowed code in the App" : "L'aplicacion pòt pas èsser installada perque conten de còde pas autorizat",
    "App can't be installed because it is not compatible with this version of ownCloud" : "L'aplicacion pòt pas èsser installada perque es pas compatibla amb aquesta version d'ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "L'aplicacion pòt pas èsser installada perque conten la balisa <shipped>true</shipped> qu'es pas autorizada per las aplicacions non inclusas per defaut",
    "Apps" : "Aplicacions",
    "General" : "Generals",
    "Storage" : "Emmagazinatge",
    "Security" : "Seguretat",
    "Encryption" : "Chiframent",
    "Sharing" : "Partiment",
    "Search" : "Recercar",
    "Updates" : "Mesas a jorn",
    "%s enter the database username and name." : "%s entratz lo nom d'utilizaire e lo nom de la basa de donadas.",
    "%s enter the database username." : "%s entratz lo nom d'utilizaire de la banca de donadas.",
    "%s enter the database name." : "%s entratz lo nom de la banca de donadas.",
    "%s you may not use dots in the database name" : "%s podètz pas utilizar de punts dins lo nom de la banca de donadas",
    "Oracle connection could not be established" : "La connexion Oracle pòt pas èsser establida",
    "Oracle username and/or password not valid" : "Nom d'utilizaire e/o senhal de la basa Oracle invalid(s)",
    "DB Error: \"%s\"" : "Error de la basa de donadas : \"%s\"",
    "Offending command was: \"%s\"" : "La requèsta en causa es : \"%s\"",
    "You need to enter either an existing account or the administrator." : "Vos cal especificar lo nom d'un compte existent, o lo de l'administrator.",
    "Offending command was: \"%s\", name: %s, password: %s" : "La requèsta en causa es : \"%s\", nom : %s, senhal : %s",
    "PostgreSQL username and/or password not valid" : "Nom d'utilizaire e/o senhal de la base PostgreSQL invalid(s)",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X es pas pres en carga e %s foncionarà pas corrèctament sus aquesta plataforma. Son utilizacion es jos vòstra responsabilitat !",
    "For the best results, please consider using a GNU/Linux server instead." : "Per obténer los melhors resultats, vos caldriá utilizar un servidor GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Sembla qu'aquesta instància %s fonciona sus un environament PHP 32-bit e open_basedir es estat configurat dins php.ini. Aquò engendre de problèmas amb los fichièrs de talha superiora a 4 Go e es doncas fòrtament desconselhat.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Suprimissètz la configuracion open_basedir de vòstre php.ini o utilizar una version PHP 64-bit.",
    "Set an admin username." : "Especificatz un nom d'utilizaire per l'administrator.",
    "Set an admin password." : "Especificatz un senhal per l'administrator.",
    "Can't create or write into the data directory %s" : "Impossible de crear, o d'escriure dedins, lo repertòri de las donadas %s",
    "Invalid Federated Cloud ID" : "ID Federated Cloud incorrècte",
    "%s shared »%s« with you" : "%s a partejat «%s» amb vos",
    "%s via %s" : "%s via %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Lo partiment de %s a fracassat perque l’infrastructura autoriza pas los partiments de tipe %i",
    "Sharing %s failed, because the file does not exist" : "Lo partiment de %s a fracassat perque lo fichièr existís pas",
    "You are not allowed to share %s" : "Sètz pas autorizat a partejar %s",
    "Sharing %s failed, because you can not share with yourself" : "Lo partiment de %s a fracassat perque podètz pas partejar amb vos-meteis",
    "Sharing %s failed, because the user %s does not exist" : "Lo partiment de %s a fracassat perque l'utilizaire %s existís pas",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Lo partiment de %s a fracassat perque l'utilizaire %s es pas membre de cap de grop al qual %s aparten",
    "Sharing %s failed, because this item is already shared with %s" : "Lo partiment de %s a fracassat perque aqueste objècte es ja partejat amb %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Lo partiment de %s a fracassat perque aqueste element es ja partejat amb l'utilizaire %s",
    "Sharing %s failed, because the group %s does not exist" : "Lo partiment de %s a fracassat perque lo grop %s existís pas",
    "Sharing %s failed, because %s is not a member of the group %s" : "Lo partiment de %s a fracassat perque %s es pas membre del grop %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Vos cal provesir un senhal per crear un ligam public, sols los ligams protegits son autorizats.",
    "Sharing %s failed, because sharing with links is not allowed" : "Lo partiment de %s a fracassat perque lo partiment per ligam es pas permés",
    "Not allowed to create a federated share with the same user" : "Pas autorizat a crear un partiment federat amb lo meteis utilizaire",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Lo partiment de %s a fracassat : impossible de trobar %s. Benlèu que lo servidor es momentanèament injonhable.",
    "Share type %s is not valid for %s" : "Lo tipe de partiment %s es pas valid per %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Lo reglatge de las permissions per %s a fracassat perque las permissions depassan las que son acordadas a %s",
    "Setting permissions for %s failed, because the item was not found" : "Lo reglatge de las permissions per %s a fracassat perque l'objècte es pas estat trobat",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Impossible de configurar la data d'expiracion. Un partiment pòt pas expirar mai de %s aprèp sa creacion",
    "Cannot set expiration date. Expiration date is in the past" : "Impossible de configurar la data d'expiracion : es dins lo passat.",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Impossible de suprimir la data d'expiracion. Los partiments devon aver una data d'expiracion.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Lo servici de partiment %s deu implementar l'interfàcia OCP\\Share_Backend",
    "Sharing backend %s not found" : "Servici de partiment %s pas trobat",
    "Sharing backend for %s not found" : "Lo servici de partiment per %s es introbable",
    "Sharing failed, because the user %s is the original sharer" : "Lo partiment a fracassat perque l'utilizaire %s es lo proprietari original",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Lo partiment de %s a fracassat perque las permissions depassan las que son acordadas a %s",
    "Sharing %s failed, because resharing is not allowed" : "Lo partiment de %s a fracassat perque lo repartatge es pas autorizat",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Lo partiment de %s a fracassat perque la font es pas estada trobada pel partiment %s.",
    "Sharing %s failed, because the file could not be found in the file cache" : "Lo partiment de %s a fracassat perque lo fichièr es pas estat trobat dins los fichièrs meses en escondedor.",
    "Cannot increase permissions of %s" : "Impossible d'aumentar las permissions de %s",
    "Files can't be shared with delete permissions" : "Los fichièrs pòdon pas èsser partejats amb las autorizacions de supression",
    "Files can't be shared with create permissions" : "Los fichièrs pòdon pas èsser partejats amb las autorizacions de creacion",
    "Expiration date is in the past" : "La data d'expiracion es dins lo passat",
    "Cannot set expiration date more than %s days in the future" : "Impossible de definir la data d'expiracion a mai de %s jorns dins lo futur",
    "Could not find category \"%s\"" : "Impossible de trobar la categoria \"%s\"",
    "A valid username must be provided" : "Un nom d'utilizaire valid deu èsser sasit",
    "A valid password must be provided" : "Un senhal valid deu èsser sasit",
    "The username is already being used" : "Aqueste nom d'utilizaire es ja utilizat",
    "User disabled" : "Utilizaire desactivat",
    "Help" : "Ajuda",
    "Settings" : "Paramètres",
    "Users" : "Utilizaires",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "L'aplicacion \"%s\" pòt pas èsser installada a causa de las dependéncias seguentas pas satisfachas : %s",
    "web services under your control" : "servicis web jos vòstre contraròtle",
    "File is currently busy, please try again later" : "Lo fichièr es actualament utilizat, tornatz ensajar pus tard",
    "Can't read file" : "Impossible de legir lo fichièr",
    "Application is not enabled" : "L'aplicacion es pas activada",
    "Authentication error" : "Error d'autentificacion",
    "Token expired. Please reload page." : "La session a expirat. Recargatz la pagina.",
    "Unknown user" : "Utilizaire desconegut",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Cap de pilòt de banca de donadas es pas installat (sqlite, mysql o postgresql).",
    "Cannot write into \"config\" directory" : "Impossible d’escriure dins lo repertòri \"config\"",
    "Cannot write into \"apps\" directory" : "Impossible d’escriure dins lo repertòri \"apps\"",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Aqueste problèma es generalament resolgut %sen donant al servidor web un accès en escritura al repertòri apps%s o en desactivant l'appstore dins lo fichièr de configuracion.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Lo problèma de permissions pòt generalament èsser resolgut %sen donant al servidor web un accès en escritura al repertòri raiç%s",
    "Setting locale to %s failed" : "Fracàs de l'especificacion dels paramètres regionals a %s",
    "Please install one of these locales on your system and restart your webserver." : "Installatz un d'aqueles paramètres regionals sus vòstre sistèma e reaviatz vòstre servidor web.",
    "Please ask your server administrator to install the module." : "Demandatz a vòstre administrator d’installar lo modul.",
    "PHP module %s not installed." : "Lo modul PHP %s es pas installat.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Lo paramètre PHP \"%s\" es pas \"%s\".",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Ajustar aqueste paramètre dins php.ini permetrà a ownCloud de foncionar tornamai",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload es a \"%s\" mentre que la valor \"0\" es esperada",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Per corregir aqueste problèma metètz <code>mbstring.func_overload</code> a <code>0</code> dins vòstre php.ini",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP sembla configurat de manièra a suprimir los blòts PHPdoc del còde. Aquò rendrà mantuna aplicacion de basa inaccessiblas.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "La rason es probablament l'utilizacion d'un escondedor / accelerator tal coma Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Los moduls PHP son estats installats mas son totjorn indicats coma mancants ?",
    "Please ask your server administrator to restart the web server." : "Demandatz a vòstre administrator servidor que reavie lo servidor web.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requesit",
    "Please upgrade your database version" : "Metètz a jorn vòstre gestionari de banca de donadas",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Cambiatz las permissions del repertòri en mòde 0770 per fin que son contengut pòsca èsser listat pels autres utilizaires.",
    "Check the value of \"datadirectory\" in your configuration" : "Verificatz la valor de \"datadirectory\" dins vòstra configuracion",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Verificatz que lo repertòri de donadas conten un fichièr \".ocdata\" a sa raiç.",
    "Could not obtain lock type %d on \"%s\"." : "Impossible d'obténer lo varrolhatge de tipe %d sus \"%s\".",
    "Storage unauthorized. %s" : "Espaci d'emmagazinatge pas autorizat. %s",
    "Storage incomplete configuration. %s" : "Configuracion de l'espaci d'emmagazinatge incompleta. %s",
    "Storage connection error. %s" : "Error de connexion a l'espaci d'emmagazinatge. %s",
    "Storage is temporarily not available" : "Espaci d'emmagazinatge temporàriament indisponible"
},
"nplurals=2; plural=(n > 1);");
